import path from "path";
import fs from "fs";

export const createReadme = async (frontendDir: string, frontendTech: string): Promise<void> => {
  const readmePath = path.join(frontendDir, "README.md");
  const readmeContent = `
    # Frontend Setup

    This project uses Node.js version ${process.version}. To ensure compatibility, please use [nvm](https://github.com/nvm-sh/nvm) to manage your Node.js versions.

    ## Instructions

    1. Install nvm (Node Version Manager) if you haven't already. Follow the instructions [here](https://github.com/nvm-sh/nvm#installing-and-updating).

    2. Use nvm to install and use the correct Node.js version:

    \`\`\`sh
    nvm install ${process.version}
    nvm use ${process.version}
    \`\`\`

    3. Install the project dependencies:

    \`\`\`sh
    npm install
    \`\`\`

    4. Follow the specific instructions for the chosen frontend technology.

    ## Frontend Technology

    The chosen frontend technology for this project is **${frontendTech}**.
    `;

  fs.writeFileSync(readmePath, readmeContent);
  console.log(`README.md created successfully at ${readmePath}\n`);
};
